from biogeme import *
from headers import *
from loglikelihood import *
from statistics import *

#パラメータの宣言
# Arguments:
#   - 1  Name for report; Typically, the same as the variable.
#   - 2  Starting value.
#   - 3  Lower bound.
#   - 4  Upper bound.
#   - 5  0: estimate the parameter, 1: keep it fixed.
#
ASC_FIVE = Beta('ASC_FIVE',0,-100,100,1,'five cte.')
ASC_TEN = Beta('ASC_TEN',0,-100,100,0,'ten cte.')
ASC_OVER = Beta('ASC_OVER',0,-100,100,0,'over cte.')
B_OFFICE = Beta('B_OFFICE',0,-100,100,0,'go office')
B_FEMALE = Beta('B_FEMALE',0,-100,100,0,'female')
B_ARRIVED = Beta('B_ARRIVED',0,-100,100,0,'arrived')
B_DO = Beta('B_DO',0,-100,100,0,'do')
B_WORK = Beta('B_WORK',0,-100,100,0,'work')
B_WORKING = Beta('B_WORKING',0,-100,100,0,'working')


# Utility functions

#変数のスケーリング
GOOFFICE_TT_SCALED = DefineVariable('GOOFFICE_TT_SCALED', GOOFFICEHOUR / 10)
ARRIVED_TT_SCALED = DefineVariable('ARRIVED_TT_SCALED', ARRIVEDHOUR / 10)

V1 = ASC_FIVE + B_DO * DOHOUR + B_WORK * WORK + B_WORKING * WORKING
V2 = ASC_TEN + B_ARRIVED * ARRIVED_TT_SCALED 
V3 = ASC_OVER + B_OFFICE * GOOFFICE_TT_SCALED + B_ARRIVED * ARRIVED_TT_SCALED 

#効用設定
V = {1: V1,
     2: V2,
     3: V3}

#選択可能性設定
av = {1: AV_FIVE,
      2: AV_TEN,
      3: AV_OVER}

# The choice model is a logit, with availability conditions
#選択モデルの定義
logprob = bioLogLogit(V,av,CHOICE)

# Defines an itertor on the data
#いてれーたの定義
rowIterator('obsIter') 

# DEfine the likelihood function for the estimation
#対数尤度関数の定義
BIOGEME_OBJECT.ESTIMATE = Sum(logprob,'obsIter')

# All observations verifying the following expression will not be
# considered for estimation
# The modeler here has developed the model only for work trips.  
# Observations such that the dependent variable CHOICE is 0 are also removed.
#条件選択
exclude = (( CHOICE != 1 ) * ( CHOICE != 2 ) * ( CHOICE != 3 )) > 0

BIOGEME_OBJECT.EXCLUDE = exclude

# Statistics
#統計量

nullLoglikelihood(av,'obsIter')
choiceSet = [1,2,3]
cteLoglikelihood(choiceSet,CHOICE,'obsIter')
availabilityStatistics(av,'obsIter')

#表示

BIOGEME_OBJECT.PARAMETERS['optimizationAlgorithm'] = "BIO"

BIOGEME_OBJECT.FORMULAS['FIVE utility'] = V1
BIOGEME_OBJECT.FORMULAS['TEN utility'] = V2
BIOGEME_OBJECT.FORMULAS['OVER utility'] = V3